@@ -19,9 +19,10 @@ names.rd_file <- function(x) {
 #' @S3method format rd_file
 format.rd_file <- function(x, ...) {
   tags <- as.list(x[[1]])
-  order <- c("docType", "name", "alias", "title", "format", "source", "usage",
-    "arguments", "value", "description", "details", "note", "section",
-    "examples", "author", "references", "seealso", "concept", "keyword")
+  order <- c("docType", "encoding", "name", "alias", "title", "format",
+    "source", "usage", "arguments", "value", "description", "details", "note",
+    "section", "examples", "author", "references", "seealso", "concept",
+    "keyword")
     
   tags <- tags[intersect(order, names(tags))]
   
