@@ -49,6 +49,8 @@ register.srcref.parsers(function(call, env) {
   
   if (out$fun) {
     out$formals <- formals(value)
+  } else if (inherits(value, "refObjectGenerator")) {
+    # Reference class
   } else {
     if (is.null(out$docType)) out$docType <- "data"
     out$str <- str_c(capture.output(str(value, max.level = 1)), 
@@ -535,7 +537,7 @@ process.docType <- function(partitum) {
     if (is.null(partitum$usage)) {
       tags <- c(tags, new_tag("usage", partitum$assignee))
     }
-    tags <- c(tags, new_tag("keyword", "dataset"))
+    tags <- c(tags, new_tag("keyword", "datasets"))
   }
   
   tags
